## $Id: export.py 12482 2015-01-16 06:52:21Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""Exporters for student related stuff.
"""
from kofacustom.sampleuni.students.interfaces import (
    ICustomStudent,
    ICustomStudentStudyCourse,
    ICustomStudentStudyLevel,
    ICustomCourseTicket,
    ICustomStudentOnlinePayment)
from waeup.kofa.students.export import (
    StudentExporter,
    StudentStudyCourseExporter,
    StudentStudyLevelExporter,
    CourseTicketExporter,
    StudentPaymentsExporter)
from waeup.kofa.utils.helpers import iface_names

class CustomStudentExporter(StudentExporter):
    """Exporter for Students.
    """

    fields = tuple(sorted(iface_names(
        ICustomStudent, omit=['loggerInfo']))) + (
        'password', 'state', 'history', 'certcode', 'is_postgrad',
        'current_level', 'current_session')

class CustomStudentStudyCourseExporter(StudentStudyCourseExporter):
    """Exporter for StudentStudyCourses.
    """

    fields = tuple(
        sorted(iface_names(ICustomStudentStudyCourse))) + ('student_id',)

class CustomStudentStudyLevelExporter(StudentStudyLevelExporter):
    """Exporter for StudentStudyLevels.
    """
    #: Fieldnames considered by this exporter
    fields = tuple(sorted(iface_names(
        ICustomStudentStudyLevel) + ['level'])) + (
        'student_id', 'number_of_tickets','certcode')

class CustomCourseTicketExporter(CourseTicketExporter):
    """Exporter for CourseTickets.
    """

    fields = tuple(sorted(iface_names(ICustomCourseTicket) +
        ['level', 'code', 'level_session'])) + ('student_id',
        'certcode', 'display_fullname')

class CustomStudentPaymentsExporter(StudentPaymentsExporter):
    """Exporter for OnlinePayment instances.
    """

    fields = tuple(
        sorted(iface_names(
            ICustomStudentOnlinePayment, exclude_attribs=False,
            omit=['display_item']))) + (
            'student_id','state','current_session')

